@@ -5,6 +5,8 @@ package testdata
 import (
 	"net/http"
 	"time"
+
+	"golang.org/x/xerrors"
 )
 
 func SampleRevive(t *time.Duration) error {
@@ -28,3 +30,7 @@ func testReviveComplexity(s string) { // want "cyclomatic: function testReviveCo
 		return
 	}
 }
+
+func testErrorStrings() {
+	_ = xerrors.New("Some error!") // want "error strings should not be capitalized or end with punctuation or a newline"
+}
